CombinedRegularizer
===================

.. currentmodule:: pykeen.regularizers

.. autoclass:: CombinedRegularizer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CombinedRegularizer.normalize

   .. rubric:: Methods Summary

   .. autosummary::

      ~CombinedRegularizer.forward

   .. rubric:: Attributes Documentation

   .. autoattribute:: normalize

   .. rubric:: Methods Documentation

   .. automethod:: forward
